/**
 * Copyright (c) 2017 Tomek Wójcik <tomek@bthlabs.pl>
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to
 * deal in the Software without restriction, including without limitation the
 * rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
 * sell copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
 * IN THE SOFTWARE.
 */

import underscore from "underscore";

import {NAVIGATION_BAR_ACTIONS} from "../lib/defs";

const DEFAULT_STATE = {
  expanded: false,
  showAboutModal: false,
  showSettingsModal: false
};

const navigationBarReducer = (state = DEFAULT_STATE, action) => {
  switch (action.type) {
    case NAVIGATION_BAR_ACTIONS.CLEANUP:
      return underscore.clone(DEFAULT_STATE);

    case NAVIGATION_BAR_ACTIONS.EXPAND:
      return underscore.extendOwn({}, state, {
        expanded: true
      });

    case NAVIGATION_BAR_ACTIONS.COLLAPSE:
      return underscore.extendOwn({}, state, {
        expanded: false
      });

    case NAVIGATION_BAR_ACTIONS.SHOW_ABOUT_MODAL:
      return underscore.extendOwn({}, state, {
        expanded: false,
        showAboutModal: true
      });

    case NAVIGATION_BAR_ACTIONS.HIDE_ABOUT_MODAL:
      return underscore.extendOwn({}, state, {
        showAboutModal: false
      });

    case NAVIGATION_BAR_ACTIONS.SHOW_SETTINGS_MODAL:
      return underscore.extendOwn({}, state, {
        expanded: false,
        showSettingsModal: true
      });

    case NAVIGATION_BAR_ACTIONS.HIDE_SETTINGS_MODAL:
      return underscore.extendOwn({}, state, {
        showSettingsModal: false
      });

    default:
      return state;
  }
};

export default navigationBarReducer;
