/**
 * Copyright (c) 2017 Tomek Wójcik <tomek@bthlabs.pl>
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to
 * deal in the Software without restriction, including without limitation the
 * rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
 * sell copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
 * IN THE SOFTWARE.
 */

import underscore from "underscore";

import {PLAYER_GAME_ACTIONS} from "../lib/defs";

const DEFAULT_STATE = {
  loading: true,
  map: "",
  weaponStats: {},
  itemStats: {},
  powerupStats: {},
  scoreChartSeries: [],
  damageChartSeries: [],
  totalsChartSeries: []
};

const processSerieData = (serie, name) => {
  if (!serie) {
    return [];
  }

  return [
    {
      "type": "pie",
      "name": name,
      "data": serie
    }
  ];
};

const playerGameReducer = (state = DEFAULT_STATE, action) => {
  switch (action.type) {
    case PLAYER_GAME_ACTIONS.CLEANUP:
      return underscore.clone(DEFAULT_STATE);

    case PLAYER_GAME_ACTIONS.LOAD_DATA:
      return underscore.extendOwn({}, state, {
        loading: true
      });

    case PLAYER_GAME_ACTIONS.PARSE_DATA:
      return underscore.extendOwn({}, state, {
        loading: false,
        map: action.data.map,
        weaponStats: action.data.weapons || {},
        itemStats: action.data.items || {},
        powerupStats: action.data.powerups || {}
      });

    case PLAYER_GAME_ACTIONS.LOAD_CHARTS_DATA:
      return underscore.extendOwn({}, state, {
        scoreChartSeries: [],
        damageChartSeries: [],
        totalsChartSeries: []
      });

    case PLAYER_GAME_ACTIONS.PARSE_CHARTS_DATA:
      return underscore.extendOwn({}, state, {
        scoreChartSeries: processSerieData(action.data.score),
        damageChartSeries: processSerieData(action.data.damage),
        totalsChartSeries: processSerieData(action.data.totals)
      });

    default:
      return state;
  }
};

export default playerGameReducer;
