/**
 * Copyright (c) 2017 Tomek Wójcik <tomek@bthlabs.pl>
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to
 * deal in the Software without restriction, including without limitation the
 * rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
 * sell copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
 * IN THE SOFTWARE.
 */

import underscore from "underscore";

import {SESSIONS_ACTIONS} from "../lib/defs";

const DEFAULT_STATE = {
  loading: true,
  day: "",
  previousDay: "",
  nextDay: "",
  games: [],
  categories: [],
  series: []
};

const sessionsReducer = (state = DEFAULT_STATE, action) => {
  switch (action.type) {
    case SESSIONS_ACTIONS.CLEANUP:
      return underscore.clone(DEFAULT_STATE);

    case SESSIONS_ACTIONS.SET_DAY:
      return underscore.extendOwn({}, state, {
        day: action.day,
        loading: true
      });

    case SESSIONS_ACTIONS.LOAD_DATA:
      return underscore.extendOwn({}, state, {
        loading: true
      });

    case SESSIONS_ACTIONS.PARSE_DATA:
      return underscore.extendOwn({}, state, {
        day: action.data.day,
        games: action.data.games,
        loading: false,
        nextDay: action.data.next_day || "",
        previousDay: action.data.previous_day || ""
      });

    case SESSIONS_ACTIONS.LOAD_CHART_DATA:
      return underscore.extendOwn({}, state, {
        categories: [],
        series: []
      });

    case SESSIONS_ACTIONS.PARSE_CHART_DATA:
      return underscore.extendOwn({}, state, {
        categories: action.categories,
        series: action.series
      });

    default:
      return state;
  }
};

export default sessionsReducer;
