/**
 * Copyright (c) 2017 Tomek Wójcik <tomek@bthlabs.pl>
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to
 * deal in the Software without restriction, including without limitation the
 * rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
 * sell copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
 * IN THE SOFTWARE.
 */

import React from "react";
import {connect} from "react-redux";

import ChartComponent from "../components/ChartComponent";
import ContainerComponent from "../components/ContainerComponent";
import LoaderComponent from "../components/LoaderComponent";
import {cleanup, loadData} from "../actions/dashboard";

class TopPlayersTableView extends React.PureComponent {
  render () {
    return (
      <table className="table table-striped table-bordered table-hover">
        <thead>
            <tr>
                <th>Player</th>
                <th>{this.props.scoreColumnTitle}</th>
            </tr>
        </thead>

        <tbody>
          {(this.props.scores.length == 0) &&
            <tr>
              <td colSpan="2"><strong>No stats :(</strong></td>
            </tr>
          }

          {this.props.scores.map(function (item, index) {
            return (
              <tr key={index}>
                <td>{item[0]}</td>
                <td>{item[1]}</td>
              </tr>
            );
          })}
        </tbody>
      </table>
    );
  }
}

TopPlayersTableView.propTypes = {
  scoreColumnTitle: React.PropTypes.string.isRequired,
  scores: React.PropTypes.array
};

class DashboardView extends React.PureComponent {
  constructor (props) {
    super(props);

    this.chartConfig = {
      "chart": {
        "type": "column"
      },
      "title": {
        "text": "Scores by map and player"
      },
      "credits": {
        "enabled": false
      },
      "yAxis": {
        "min": -10,
        "title": {
            "text": "Score"
        }
      },
      "plotOptions": {
        "column": {
          "pointPadding": 0.2,
          "borderWidth": 0
        }
      }
    };
  }
  componentDidMount () {
    if (!this.props.day) {
      this.props.dispatch(loadData(this.props.dispatch));
    }
  }
  componentWillUnmount () {
    this.props.dispatch(cleanup());
  }
  render () {
    return (
      <ContainerComponent>
        <h2>Dashboard</h2>

        <ChartComponent
          config={this.chartConfig}
          categories={this.props.categories}
          series={this.props.series}
          subtitle={this.props.day} />

        <div className="row">
          <div className="col-sm-6">
            <h2>Fraggers of the month</h2>

            <TopPlayersTableView
              scoreColumnTitle="Frags"
              scores={this.props.fraggersOfTheMonth} />
          </div>

          <div className="col-sm-6">
            <h2>Emos of the month</h2>

            <TopPlayersTableView
              scoreColumnTitle="Suicides"
              scores={this.props.emosOfTheMonth} />
          </div>
        </div>

        <LoaderComponent visible={this.props.loading} />
      </ContainerComponent>
    );
  }
}

DashboardView.propTypes = {
  loading: React.PropTypes.bool.isRequired,
  day: React.PropTypes.string.isRequired,
  emosOfTheMonth: React.PropTypes.array.isRequired,
  fraggersOfTheMonth: React.PropTypes.array.isRequired,
  categories: React.PropTypes.array.isRequired,
  series: React.PropTypes.array.isRequired
};

const mapStateToProps = (state, props) => {
  return state.dashboard;
};

const reduxContainer = connect(mapStateToProps)(DashboardView);

export default reduxContainer;
