# -*- coding: utf-8 -*-
# Copyright (c) 2017 Tomek Wójcik <tomek@bthlabs.pl>
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
#

"""
q3stats.database
================

This module contains database utilities.
"""

import sqlalchemy as sa
from sqlalchemy.ext.declarative import declarative_base

#: Base for declarative models
Base = declarative_base()

#: Current SQLAlchemy engine
db_engine = None

#: Current SQLAlchemy session
db_session = None


def create_engine(config):
    """Creates and initializes engine according to *config* dictionary.

    Returns the initialized engine."""
    engine = sa.create_engine(
        config['SQLALCHEMY_URL'], **config.get('SQLALCHEMY_OPTS', {})
    )

    return engine


def create_session(engine, config, scoped=True):
    """Creates a session factory bound to *engine* according to *config*
    dictionary. If *scoped* is ``True`` then the session will be scoped.
    Otherwise, it'll be a standard ``sessionmaker``.

    Returns the initialized session factory."""
    Session = sa.orm.sessionmaker(
        bind=engine, **config.get('SQLALCHEMY_SESSION_OPTS', {})
    )

    if scoped:
        return sa.orm.scoped_session(Session)

    return Session
