# -*- coding: utf-8 -*-
# Copyright (c) 2017 Tomek Wójcik <tomek@bthlabs.pl>
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
#

"""
q3stats.lib.config
==================

This module contains configuration handling functions.
"""

import os

from flask import Config

#: Default configuration file name.
DEFAULT_CONFIG_FILE = 'development.cfg'


def get_config_path(config_path=None):
    """Returns an absolute path to a config file."""
    if config_path is None:
        config_path = os.environ.get(
            'Q3STATS_CONFIG_FILE', DEFAULT_CONFIG_FILE
        )

    if not os.path.isabs(config_path):
        config_path = os.path.abspath(os.path.join(
            os.getcwd(), config_path
        ))

    return config_path


def get_config(config_path=None):
    """Returns an instance of ``flask.Config`` class with config loaded from
    *config_path*."""
    config_path = get_config_path(config_path)
    dirname, basename = os.path.split(config_path)

    config = Config(dirname)
    config.from_pyfile(basename)

    return config
