# -*- coding: utf-8 -*-
# Copyright (c) 2017 Tomek Wójcik <tomek@bthlabs.pl>
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
#

"""
q3stats.web_app.blueprints.api_v1.views.dashboard
=================================================

This module contains the APIv1 dashboard views.
"""

from flask import abort, current_app, jsonify

from q3stats.web_app.blueprints.api_v1 import api_v1_blueprint
from q3stats.lib import defs, queries


@api_v1_blueprint.route('/dashboard')
def get_api_v1_dashboard():
    """Returns data for the Dashboard view."""
    dates = queries.get_game_dates(current_app.db_session)
    fotm = queries.get_top_players(current_app.db_session)
    eotm = queries.get_top_players(current_app.db_session, agg_by='suicides')

    return jsonify({
        'day': dates[0].strftime(defs.DATE_FORMAT),
        'fotm': fotm,
        'eotm': eotm
    })
