# -*- coding: utf-8 -*-
# Copyright (c) 2017 Tomek Wójcik <tomek@bthlabs.pl>
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
#

"""
q3stats.web_app.blueprints.frontend.views
=========================================

This module contains the frontend views.
"""

import os
import shutil
import tarfile
import tempfile

from flask import current_app, abort, redirect, render_template, request,\
    url_for

from q3stats.lib.scripts.import_games import script_main as importer
from q3stats.web_app.blueprints.frontend import frontend_blueprint


@frontend_blueprint.route('/', methods=['GET'])
def get_frontend_index():
    """Renders the application."""
    return render_template('index.html')


@frontend_blueprint.route('/sessions/', methods=['GET'])
@frontend_blueprint.route('/sessions/<day>', methods=['GET'])
def get_frontend_sessions(day=None):
    """Redirects UA to Sessions view."""
    return redirect("/#/sessions/%s" % (day or "",))


@frontend_blueprint.route(
    '/players/<player>/game/<game_uuid>', methods=['GET']
)
def get_frontend_player_game(player, game_uuid):
    """Redirects UA to Player Game view."""
    return redirect("/#/players/%s/game/%s" % (player, game_uuid))


@frontend_blueprint.route('/players/', methods=['GET'])
@frontend_blueprint.route('/players/<player>', methods=['GET'])
def get_frontend_players(player=None):
    """Redirects UA to Players view."""
    return redirect("/#/players/%s" % (player or "",))


@frontend_blueprint.route('/receivestats', methods=['POST'])
def post_frontend_receivestats():
    """Receives a tarball with stats, extracts it and imports the games."""
    if 'stats' not in request.files:
        abort(400)

    pack = request.files['stats']

    work_dir = tempfile.mkdtemp()

    try:
        with tarfile.open('stats.tar', 'r', pack.stream) as pack_f:
            pack_f.extractall(work_dir)

        importer([work_dir], current_app.config)  # h4x0r
    finally:
        shutil.rmtree(work_dir)

    return 'OK', 200
