# -*- coding: utf -*-

import mock

from q3stats.testing import BaseQ3StatsWebAppTestCase
from q3stats.web_app.blueprints.api_v1.views import charts as views_mod


class Test_GetAPIv1ChartsDay(BaseQ3StatsWebAppTestCase):
    def test_invalid_day(self):
        with self.app.test_request_context():
            rsp = self.client.get('/api/v1/charts/day/spam')
            assert rsp.status_code == 400

    def test_ok(self):
        fake_data = (
            ['Q3DM7', 'Q3DM17'],
            [
                {
                    'data': [30, 30],
                    'name': 'tomekwojcik'
                },
                {
                    'data': [29, 29],
                    'name': 'Player 1'
                }
            ]
        )

        with mock.patch.object(views_mod.charts, 'get_day_chart',
                               return_value=fake_data):
            with self.app.test_request_context():
                rsp = self.client.get('/api/v1/charts/day/2017-02-15')
                assert rsp.status_code == 200

                assert rsp.json['day'] == '2017-02-15'
                assert rsp.json['maps'] == fake_data[0]
                assert rsp.json['scores'] == fake_data[1]
